##  Field Permissions
The Fields section contains permissions for all fields that exist within a fact sheet type. These permissions are displayed following the structure of sections and subsections as they appear on the fact sheet page.
